==> connectome-workbench_1.1.1.orig.tar.gz: workbench-1.1.1/src/Files/EventMapYokingSelectMap.h <==
#ifndef __EVENT_MAP_YOKING_SELECT_MAP_H__
#define __EVENT_MAP_YOKING_SELECT_MAP_H__

/*LICENSE_START*/
/*
 *  Copyright (C) 2014 Washington University School of Medicine
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with this program; if not, write to the Free Software Foundation, Inc.,
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
/*LICENSE_END*/


#include "Event.h"
#include "MapYokingGroupEnum.h"

namespace caret {

    class CaretMappableDataFile;
    
    class EventMapYokingSelectMap : public Event {
        
    public:
        EventMapYokingSelectMap(const MapYokingGroupEnum::Enum mapYokingGroup,
                                const CaretMappableDataFile* caretMappableDataFile,
                                const int32_t mapIndex,
                                const bool selectionStatus);
        
        virtual ~EventMapYokingSelectMap();
        
        MapYokingGroupEnum::Enum getMapYokingGroup() const;
        
        const CaretMappableDataFile* getCaretMappableDataFile() const;
        
        int32_t getMapIndex() const;
        
        bool getSelectionStatus() const;

        // ADD_NEW_METHODS_HERE

    private:
        EventMapYokingSelectMap(const EventMapYokingSelectMap&);

        EventMapYokingSelectMap& operator=(const EventMapYokingSelectMap&);
        
        const MapYokingGroupEnum::Enum m_mapYokingGroup;
        
        const CaretMappableDataFile* m_caretMappableDataFile;
        
        const int32_t m_mapIndex;
        
        const bool m_selectionStatus;

        // ADD_NEW_MEMBERS_HERE

    };
    
#ifdef __EVENT_MAP_YOKING_SELECT_MAP_DECLARE__
    // <PLACE DECLARATIONS OF STATIC MEMBERS HERE>
#endif // __EVENT_MAP_YOKING_SELECT_MAP_DECLARE__

} // namespace
#endif  //__EVENT_MAP_YOKING_SELECT_MAP_H__

==> connectome-workbench_2.1.0.orig.tar.gz: workbench-2.1.0/src/Files/EventMapYokingSelectMap.h <==
#ifndef __EVENT_MAP_YOKING_SELECT_MAP_H__
#define __EVENT_MAP_YOKING_SELECT_MAP_H__

/*LICENSE_START*/
/*
 *  Copyright (C) 2014 Washington University School of Medicine
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with this program; if not, write to the Free Software Foundation, Inc.,
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
/*LICENSE_END*/


#include "Event.h"
#include "MapYokingGroupEnum.h"

namespace caret {

    class AnnotationTextSubstitutionFile;
    class CaretMappableDataFile;
    class HistologySlicesFile;
    class MediaFile;
    
    class EventMapYokingSelectMap : public Event {
        
    public:
        EventMapYokingSelectMap(const MapYokingGroupEnum::Enum mapYokingGroup,
                                const CaretMappableDataFile* caretMappableDataFile,
                                const AnnotationTextSubstitutionFile* annotationTextSubstitutionFile,
                                const HistologySlicesFile* histologySlicesFile,
                                const MediaFile* mediaFile,
                                const int32_t mapIndex,
                                const MapYokingGroupEnum::MediaAllFramesStatus mediaAllFramesStatus,
                                const bool selectionStatus);
        
        virtual ~EventMapYokingSelectMap();
        
        MapYokingGroupEnum::Enum getMapYokingGroup() const;
        
        const CaretMappableDataFile* getCaretMappableDataFile() const;
        
        const AnnotationTextSubstitutionFile* getAnnotationTextSubstitutionFile() const;
        
        const HistologySlicesFile* getHistologySlicesFile() const;
        
        const MediaFile* getMediaFile() const;
        
        int32_t getMapIndex() const;
        
        // ADD_NEW_METHODS_HERE

    private:
        EventMapYokingSelectMap(const EventMapYokingSelectMap&);

        EventMapYokingSelectMap& operator=(const EventMapYokingSelectMap&);
        
        const MapYokingGroupEnum::Enum m_mapYokingGroup;
        
        const CaretMappableDataFile* m_caretMappableDataFile;
        
        const AnnotationTextSubstitutionFile* m_annotationTextSubstitutionFile;
        
        const HistologySlicesFile* m_histologySlicesFile;
        
        const MediaFile* m_mediaFile;
        
        const int32_t m_mapIndex;

        // ADD_NEW_MEMBERS_HERE

    };
    
#ifdef __EVENT_MAP_YOKING_SELECT_MAP_DECLARE__
    // <PLACE DECLARATIONS OF STATIC MEMBERS HERE>
#endif // __EVENT_MAP_YOKING_SELECT_MAP_DECLARE__

} // namespace
#endif  //__EVENT_MAP_YOKING_SELECT_MAP_H__
